# `gromacs-helix`

A simple CLI tool for GROMACS

**Usage**:

```console
$ gromacs-helix [OPTIONS] COMMAND [ARGS]...
```

**Options**:

- `--install-completion`: Install completion for the current shell.
- `--show-completion`: Show completion for the current shell, to copy it or customize the installation.
- `--help`: Show this message and exit.

**Commands**:

- `load`: Load the portal gun
- `shoot`: Shoot the portal gun

## `gromacs-helix load`

Load the portal gun

**Usage**:

```console
$ gromacs-helix load [OPTIONS]
```

**Options**:

- `--help`: Show this message and exit.

## `gromacs-helix shoot`

Shoot the portal gun

**Usage**:

```console
$ gromacs-helix shoot [OPTIONS]
```

**Options**:

- `--help`: Show this message and exit.
